@@ -158,7 +158,7 @@ static const char *context_line_color  = "";	/* default color pair */
 	    of 1 ("\33[I"), i.e., it performs pure movement to the next
 	    tab stop, without any clearing of either content or screen
 	    attributes (including background color); try
-	       echo -ne 'asdfqwerzxcv\rASDF\tZXCV\n'
+	       printf 'asdfqwerzxcv\rASDF\tZXCV\n'
 	    in a bash(1) shell to demonstrate this.  This is not what the
 	    user would instinctively expect of HT (but is ok for CHT).
 	    The instinctive behavior would include clearing the terminal
@@ -724,32 +724,10 @@ print_line_middle (const char *beg, const char *lim,
   size_t match_offset;
   const char *cur = beg;
   const char *mid = NULL;
-  char *buf;
-  const char *ibeg;
 
-  /* XXX - should not be needed anymore now that we use RE_ICASE.
-     Revisit after 2.6.x stabilizes.  */
-  if (match_icase
-#ifdef MBS_SUPPORT
-      && MB_CUR_MAX == 1
-#endif
-     )
-    {
-      int i = lim - beg;
-
-      ibeg = buf = xmalloc(i);
-      while (--i >= 0)
-	buf[i] = tolower((unsigned char) beg[i]);
-    }
-  else
-    {
-      buf = NULL;
-      ibeg = beg;
-    }
-
-  while (   lim > cur
-	 && ((match_offset = execute(ibeg, lim - beg, &match_size,
-				     ibeg + (cur - beg))) != (size_t) -1))
+  while (cur < lim
+	 && ((match_offset = execute(beg, lim - beg, &match_size,
+				     beg + (cur - beg))) != (size_t) -1))
     {
       char const *b = beg + match_offset;
 
@@ -793,8 +771,6 @@ print_line_middle (const char *beg, const char *lim,
       cur = b + match_size;
     }
 
-  free (buf);	/* XXX */
-
   if (only_matching)
     cur = lim;
   else if (mid)
@@ -1629,7 +1605,8 @@ get_nondigit_option (int argc, char *const *argv, int *default_context)
 
   was_digit = 0;
   this_digit_optind = optind;
-  while (opt = getopt_long (argc, argv, short_options, long_options, NULL),
+  while (opt = getopt_long (argc, (char **) argv, short_options, long_options,
+                            NULL),
 	 '0' <= opt && opt <= '9')
     {
       if (prev_digit_optind != this_digit_optind || !was_digit)
@@ -2033,13 +2010,15 @@ main (int argc, char **argv)
             show_help = 1;
         } else
           color_option = 2;
-        if(color_option == 2) {
-          if(isatty(STDOUT_FILENO) && getenv("TERM") &&
-	     strcmp(getenv("TERM"), "dumb"))
-                  color_option = 1;
-          else
-            color_option = 0;
-        }
+        if (color_option == 2)
+	  {
+	    char const *t;
+	    if (isatty (STDOUT_FILENO) && (t = getenv ("TERM"))
+		&& strcmp (t, "dumb"))
+	      color_option = 1;
+	    else
+	      color_option = 0;
+	  }
 	break;
 
       case EXCLUDE_OPTION:
@@ -2066,7 +2045,8 @@ main (int argc, char **argv)
       case INCLUDE_OPTION:
 	if (!included_patterns)
 	  included_patterns = new_exclude ();
-	add_exclude (included_patterns, optarg, EXCLUDE_INCLUDE);
+	add_exclude (included_patterns, optarg,
+		     EXCLUDE_WILDCARDS | EXCLUDE_INCLUDE);
 	break;
 
       case GROUP_SEPARATOR_OPTION:
